package com.zipcodewilmington.phonebook;

import org.junit.Assert;
import org.junit.Test;

import java.util.ArrayList;

/**
 * Created by leon on 1/23/18.
 */
public class PhoneBookTest {

    @Test
    public void testHasEntry() {
        // Given
        PhoneBook book = new PhoneBook();
        String name = "Dan";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-1222");

        book.add(name, phoneNumber);

        //When
        boolean actualOutput = book.hasEntry(name);

        //Then
        Assert.assertTrue(actualOutput);

    }

    @Test
    public void testAdd() {
        //Given
        PhoneBook book = new PhoneBook();
        String name = "Ravi";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-1222");
        phoneNumber.add("300-111-1223");

        //When
        book.add(name, phoneNumber);

        //Then
        Assert.assertEquals(1, book.size());


    }

    @Test
    public void testAddIndvNum() {
        //Given
        PhoneBook book = new PhoneBook();
        String name = "Ravi";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-1222");
        phoneNumber.add("300-111-1223");
        //When
        book.addIndvNum(name, "300-111-1224");
        String expOut = "300-111-1224";
        ArrayList<String> list = book.lookup(name);
        String actOut = list.get(2);

        //Then
        Assert.assertEquals(expOut, actOut);


    }

    @Test
    public void testLookup() {
        //Given
        PhoneBook book = new PhoneBook();
        String name = "John";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-2222");
        phoneNumber.add("300-111-2223");
        book.add(name, phoneNumber);
        String expNum1 = "300-111-2222";
        String expNum2 = "300-111-2223";

        //When
        ArrayList<String> actNumList = book.lookup(name);
        String actNum1 = actNumList.get(0);
        String actNum2 = actNumList.get(1);

        //Then
        Assert.assertEquals(expNum1, actNum1);
        Assert.assertEquals(expNum2, actNum2);


    }

    @Test
    public void testRemove() {
        //Given
        PhoneBook book = new PhoneBook();
        String name = "Jane";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-1222");
        phoneNumber.add("300-111-1223");
        book.add(name, phoneNumber);
        String remNum = "300-111-1223";

        //When
        book.remove(name, remNum);
        ArrayList<String> actNumList = book.lookup(name);

        //Then
        Assert.assertEquals(1, actNumList.size());

    }

    @Test
    public void testRemoveRecord() {
        //Given
        PhoneBook book = new PhoneBook();
        String name1 = "Jimmy";
        String name2 = "Jimmys";
        ArrayList<String> phoneNumber1 = new ArrayList<>();
        phoneNumber1.add("300-111-1222");
        phoneNumber1.add("300-111-1223");
        book.add(name1, phoneNumber1);
        ArrayList<String> phoneNumber2 = new ArrayList<>();
        phoneNumber2.add("300-111-2223");
        phoneNumber2.add("300-111-2224");
        book.add(name2, phoneNumber2);

        //When
        book.removeRecord(name2, phoneNumber2);

        //Then
        Assert.assertEquals(1, book.size());

    }

    @Test
    public void testReverseLookup() {
        //Given
        PhoneBook book = new PhoneBook();
        String name = "Franny";
        ArrayList<String> phoneNumber = new ArrayList<>();
        phoneNumber.add("300-111-1222");
        phoneNumber.add("300-111-1223");
        book.add(name, phoneNumber);

        //When
        String actName = book.reverseLookup(phoneNumber);

        //Then
        Assert.assertEquals("Franny", actName);


    }

    @Test
    public void testListNmAndNums() {
        //Given
        PhoneBook book = new PhoneBook();
        String name1 = "GG";
        String name2 = "HH";
        ArrayList<String> phoneNumber1 = new ArrayList<>();
        phoneNumber1.add("300-111-1222");
        phoneNumber1.add("300-111-1223");
        book.add(name1, phoneNumber1);
        ArrayList<String> phoneNumber2 = new ArrayList<>();
        phoneNumber2.add("300-111-1333");
        phoneNumber2.add("300-111-1334");
        book.add(name2, phoneNumber2);

        String expOut = "\nName: GG Number : [300-111-1222, 300-111-1223]" + "\nName: HH Number : [300-111-1333, 300-111-1334]";

        //When
        String actOut = book.listNameAndNumbers();

        //Then
        Assert.assertEquals(expOut, actOut);


    }
}



